@@ -428,7 +428,7 @@ _draw_shape (GogRenderer *renderer, GOPath const *path, gboolean fill, gboolean
 	g_return_if_fail (renderer->cur_style != NULL);
 	g_return_if_fail (GO_IS_PATH (path));
 
-        style = renderer->cur_style;
+    style = renderer->cur_style;
 
 	line_options = go_path_get_options (path);
 	width = stroke ? _grc_line_size (renderer, style->line.width,
@@ -1253,6 +1253,18 @@ _free_marker_data (GogRenderer *rend)
 	}
 }
 
+void
+gog_renderer_draw_color_map (GogRenderer *rend, GogAxisColorMap const *map,
+                             int discrete, gboolean horizontal,
+                             GogViewAllocation const *rect)
+{
+	cairo_save (rend->cairo);
+	cairo_translate (rend->cairo, rect->x, rect->y);
+	gog_axis_color_map_to_cairo (map, rend->cairo, discrete, horizontal,
+	                             rect->w, rect->h);
+	cairo_restore (rend->cairo);
+}
+
 void
 gog_renderer_push_style (GogRenderer *rend, GOStyle const *style)
 {
