@@ -79,6 +79,16 @@ void  gog_renderer_draw_selection_rectangle	(GogRenderer *renderer, GogViewAlloc
 
 void  gog_renderer_draw_marker	  (GogRenderer *rend, double x, double y);
 
+#ifndef GOFFICE_WITH_GTK
+typedef enum
+{
+  GTK_JUSTIFY_LEFT,
+  GTK_JUSTIFY_RIGHT,
+  GTK_JUSTIFY_CENTER,
+  GTK_JUSTIFY_FILL
+} GtkJustification;
+#endif
+
 void  gog_renderer_draw_text	  (GogRenderer *rend, char const *text,
 				   GogViewAllocation const *pos,
 				   GOAnchorType anchor,
@@ -106,6 +116,10 @@ void  gog_renderer_get_text_AABR  (GogRenderer *rend, char const *text,
 				   gboolean use_markup, GOGeometryAABR *aabr,
                                    double max_width);
 
+void  gog_renderer_draw_color_map	(GogRenderer *rend, GogAxisColorMap const *map,
+	                                 int discrete, gboolean horizontal,
+	                                 GogViewAllocation const *rect);
+
 void  gog_renderer_push_style     	(GogRenderer *rend, GOStyle const *style);
 void  gog_renderer_pop_style      	(GogRenderer *rend);
 
