@@ -993,7 +993,7 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 			interpolations[i] = GO_LINE_INTERPOLATION_SPLINE;
 
 		if (!is_area_plot)
-			points[i] = g_malloc (sizeof (Point) * (lengths[i]));
+			points[i] = g_malloc (sizeof (Point) * (type == GOG_1_5D_NORMAL? lengths[i]: num_elements));
 
 		errors[i] = series[i]->errors;
 		if (gog_error_bar_is_visible (series[i]->errors))
